#
# spec file for package openQA
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# can't use linebreaks here!
%define openqa_services openqa-webui.service openqa-gru.service openqa-websockets.service openqa-scheduler.service 
%define openqa_worker_services openqa-worker.target openqa-worker@.service openqa-worker-no-cleanup@.service openqa-slirpvde.service openqa-vde_switch.service

%if %{undefined tmpfiles_create}
%define tmpfiles_create() \
/usr/bin/systemd-tmpfiles --create %{?*} || : \ 
%{nil}
%endif

%if %suse_version >= 1730
%ifarch x86_64
%bcond_without tests
%else
%bcond_with tests
%endif
%else
%bcond_with tests
%endif

Name:           openQA
Version:        4.4.1497257618.89b04ed8
Release:        1.1
Summary:        The openQA web-frontend, scheduler and tools
License:        GPL-2.0+
Group:          Development/Tools/Other
Url:            http://os-autoinst.github.io/openQA/
Source0:        %{name}-%{version}.tar.xz
# a workaround for set_version looking at random files (so we can't name it .tar.xz)
# use update-cache to update it
Source1:        cache.txz
Source101:      update-cache.sh
ExcludeArch:    i586
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Requires(post): sqlite3
BuildRequires:  os-autoinst
Requires:       openQA-client = %{version}
Requires:       openQA-common = %{version}
Requires:       perl(URI)
BuildRequires:  systemd
BuildRequires:  rubygem(sass)
# needed for openid support
Requires:       perl(LWP::Protocol::https)
Recommends:     apparmor-profiles
Recommends:     apparmor-utils
Recommends:     apache2
Recommends:     logrotate
# for postgresql
Recommends:     perl(DateTime::Format::Pg) perl(DBD::Pg)
# runtime requirements that also the testsuite needs
%define t_requires perl(DBD::SQLite) perl(DBIx::Class) perl(Config::IniFiles) perl(SQL::Translator) perl(Date::Format) perl(File::Copy::Recursive) perl(DateTime::Format::SQLite) perl(Net::OpenID::Consumer) perl(Mojolicious::Plugin::RenderFile) perl(Mojolicious::Plugin::AssetPack) perl(aliased) perl(Config::Tiny) perl(DBIx::Class::DynamicDefault) perl(DBIx::Class::Schema::Config) perl(DBIx::Class::Storage::Statistics) perl(IO::Socket::SSL) perl(Data::Dump) perl(DBIx::Class::OptimisticLocking) perl(Text::Markdown) perl(Net::DBus) perl(IPC::Run) perl(Archive::Extract) perl(CSS::Minifier::XS) perl(JavaScript::Minifier::XS) perl(Time::ParseDate) perl(Sort::Versions) perl(Mojo::RabbitMQ::Client) perl(BSD::Resource)
BuildRequires:  perl(Mojolicious) >= 7.24
BuildRequires:  perl(Mojolicious::Plugin::AssetPack) >= 1.36
# critical bug fix
BuildRequires:  perl(DBIx::Class) >= 0.082801
Requires:       perl(DBIx::Class) >= 0.082801
# needed for test suite
Requires:       git-core
# needed for saving needles optimized
Requires:       optipng
BuildRequires:  %{t_requires}
Requires:       dbus-1
BuildRequires:  fdupes
%if %{with tests}
BuildRequires:  perl-App-cpanminus
BuildRequires:  phantomjs
BuildRequires:  perl(Mojo::RabbitMQ::Client)
BuildRequires:  perl(Perl::Critic)
BuildRequires:  perl(Perl::Tidy)
BuildRequires:  perl(Selenium::Remote::Driver)
BuildRequires:  perl(Test::Compile)
BuildRequires:  perl(Test::MockObject)
BuildRequires:  perl(Test::Warnings)
%endif
Requires(post): perl(DBIx::Class::DeploymentHandler)
Requires(post): perl(SQL::SplitStatement)
Requires(post): coreutils
%if 0%{?suse_version} >= 1330
Requires(pre):  group(nogroup)
%endif
%{?systemd_requires}
BuildArch:      noarch
# we need to have the same sha1 as expected
%requires_eq    perl-Mojolicious-Plugin-AssetPack

%description
openQA is a testing framework that allows you to test GUI applications on one
hand and bootloader and kernel on the other. In both cases, it is difficult to
script tests and verify the output. Output can be a popup window or it can be
an error in early boot even before init is executed.

openQA is an automated test tool that makes it possible to test the whole
installation process of an operating system. It uses virtual machines to
reproduce the process, check the output (both serial console and screen) in
every step and send the necessary keystrokes and commands to proceed to the
next. openQA can check whether the system can be installed, whether it works
properly in 'live' mode, whether applications work or whether the system
responds as expected to different installation options and commands.

Even more importantly, openQA can run several combinations of tests for every
revision of the operating system, reporting the errors detected for each
combination of hardware configuration, installation options and variant of the
operating system.

%package common
Summary:        The openQA common tools for web-frontend and workers
Group:          Development/Tools/Other
Requires:       %{t_requires}
Requires:       perl(Mojolicious) >= 7.24

%description common
This package contain shared resources for openQA web-frontend and 
openQA workers.

%package worker
Summary:        The openQA worker
Group:          Development/Tools/Other
PreReq:         openQA-common = %{version}
Requires(post): coreutils
Requires(post): os-autoinst >= 4.4
Requires:       openQA-client = %{version}
Requires:       os-autoinst < 5
Recommends:     qemu
Requires:       perl(SQL::SplitStatement)
%if 0%{?suse_version} >= 1330
Requires(pre):  group(nogroup)
%endif

%description worker
The openQA worker manages test engine (provided by os-autoinst package).

%package client
Summary:        Client tools for remote openQA management
Group:          Development/Tools/Other
Requires:       perl(Config::IniFiles)
Requires:       perl(Data::Dump)
Requires:       perl(Getopt::Long)
Requires:       perl(JSON)
Requires:       perl(Mojolicious)

%description client
Tools and support files for openQA client script. Client script is
a convenient helper for interacting with openQA webui REST API.

%package doc
Summary:        The openQA documentation
Group:          Development/Tools/Other

%description doc
Documentation material covering installation, configuration, basic test writing, etc.
Covering both openQA and also os-autoinst test engine.

%prep
%setup -a1

%build
make

%check
#for double checking
%if %{with tests}
cpanm --installdeps --with-feature=test . 
%endif

# we don't really need the tidy test
rm -f t/00-tidy.t

%if %{with tests}
#make test
OBS_RUN=1 prove -r -j2 -v
%endif

%install
%make_install

mkdir -p %{buildroot}/usr/share/openqa/etc/openqa
ln -s /etc/openqa/openqa.ini %{buildroot}/usr/share/openqa/etc/openqa/openqa.ini
ln -s /etc/openqa/database.ini %{buildroot}/usr/share/openqa/etc/openqa/database.ini
mkdir -p %{buildroot}%{_bindir}
ln -s /usr/share/openqa/script/client %{buildroot}%{_bindir}/openqa-client

cd %buildroot
grep -rl /usr/bin/env . | while read file; do
  sed -e 's,/usr/bin/env perl,/usr/bin/perl,' -i $file
done
mkdir -p %{buildroot}%{_sbindir}
for i in webui gru worker scheduler websockets slirpvde vde_switch; do
	ln -s ../sbin/service %{buildroot}%{_sbindir}/rcopenqa-$i
done
#
install -D -m 644 /dev/null %{buildroot}%{_localstatedir}/log/openqa
install -m 0644 %_sourcedir/openQA.changes %{buildroot}%{_datadir}/openqa/public/Changelog
#
mkdir %{buildroot}%{_localstatedir}/lib/openqa/pool/1
mkdir %{buildroot}%{_localstatedir}/lib/openqa/cache
#
%fdupes %buildroot/%_prefix

%pre
getent passwd geekotest >/dev/null || \
	/usr/sbin/useradd -r -g nogroup -c "openQA user" \
	-d /var/lib/openqa geekotest

%service_add_pre %openqa_services

%pre common
if [ "$1" = 1 ]; then
  # upgrade from openQA -> openQA-common (before -> after package split)
  # old data needs to be moved to new locations else cpio fail during package deploying
  if [ -d "%{_localstatedir}/lib/openqa/" -a ! -d "%{_localstatedir}/lib/openqa/share" ]; then
    echo "### performing migration of openQA data"
    mkdir "%{_localstatedir}/lib/openqa/share"
    if [ -e "%{_localstatedir}/lib/openqa/factory" ]; then
      echo "### moving %{_localstatedir}/lib/openqa/factory to %{_localstatedir}/lib/openqa/share/"
      mv "%{_localstatedir}/lib/openqa/factory" "%{_localstatedir}/lib/openqa/share/"
    fi
  fi
fi

%pre worker
if ! getent passwd _openqa-worker >/dev/null; then
  /usr/sbin/useradd -r -g nogroup -c "openQA worker" \
    -d /var/lib/empty _openqa-worker
  # might fail for non-kvm workers (qemu package owns the group)
  /usr/sbin/usermod _openqa-worker -a -G kvm || :
fi

%service_add_pre %openqa_worker_services

%post
# install empty log file
if [ ! -e /var/log/openqa ]; then
        install -D -m 644 -o geekotest /dev/null %{_localstatedir}/log/openqa || :
fi

if [ $1 -eq 1 ]; then
        echo "### copy and edit /etc/apache2/vhosts.d/openqa.conf.template!"
        echo "### run sudo /usr/share/openqa/script/fetchneedles"

else
	if [ -d "%{_localstatedir}/lib/openqa/share/testresults" ]; then
           # remove the symlink
           rm "%{_localstatedir}/lib/openqa/testresults"
           mv "%{_localstatedir}/lib/openqa/share/testresults" "%{_localstatedir}/lib/openqa/"
        fi
fi

%service_add_post %openqa_services

%post worker
%tmpfiles_create %{_tmpfilesdir}/openqa.conf
%service_add_post %openqa_worker_services

%preun
%service_del_preun %openqa_services

%preun worker
%service_del_preun %openqa_worker_services

%postun
%service_del_postun %openqa_services
%restart_on_update boot.apparmor

%postun worker
%service_del_postun %openqa_worker_services

%files
%defattr(-,root,root)
%doc README.asciidoc
%{_sbindir}/rcopenqa-gru
%{_sbindir}/rcopenqa-scheduler
%{_sbindir}/rcopenqa-websockets
%{_sbindir}/rcopenqa-webui
%dir %{_sysconfdir}/openqa
%config(noreplace) %attr(-,geekotest,root) %{_sysconfdir}/openqa/openqa.ini
%config(noreplace) %attr(-,geekotest,root) %{_sysconfdir}/openqa/database.ini
%dir %{_datadir}/openqa
%dir %{_datadir}/openqa/etc
%dir %{_datadir}/openqa/etc/openqa
%{_datadir}/openqa/etc/openqa/openqa.ini
%{_datadir}/openqa/etc/openqa/database.ini
%config %{_sysconfdir}/logrotate.d
%config(noreplace) %{_sysconfdir}/dbus-1/system.d/org.opensuse.openqa.conf
# apache vhost
%dir %{_sysconfdir}/apache2
%dir %{_sysconfdir}/apache2/vhosts.d
%config %{_sysconfdir}/apache2/vhosts.d/openqa.conf.template
%config %{_sysconfdir}/apache2/vhosts.d/openqa-common.inc
%config %{_sysconfdir}/apache2/vhosts.d/openqa-ssl.conf.template
# apparmor profile
%dir %{_sysconfdir}/apparmor.d
%config %{_sysconfdir}/apparmor.d/usr.share.openqa.script.openqa
# init
%dir %{_unitdir}
%{_unitdir}/openqa-webui.service
%{_unitdir}/openqa-gru.service
%{_unitdir}/openqa-scheduler.service
%{_unitdir}/openqa-websockets.service
# web libs
%dir %{_datadir}/openqa
%{_datadir}/openqa/templates
%{_datadir}/openqa/public
%{_datadir}/openqa/assets
%{_datadir}/openqa/dbicdh
%{_datadir}/openqa/script/check_dependencies
%{_datadir}/openqa/script/clean_needles
%{_datadir}/openqa/script/create_admin
%{_datadir}/openqa/script/fetchneedles
%{_datadir}/openqa/script/initdb
%{_datadir}/openqa/script/openqa
%{_datadir}/openqa/script/openqa-scheduler
%{_datadir}/openqa/script/openqa-websockets
%{_datadir}/openqa/script/upgradedb
%{_datadir}/openqa/script/modify_needle
# TODO: define final user
%defattr(-,geekotest,root)
# attention: never package subdirectories owned by a user other
# than root as that opens a security hole!
%dir %{_localstatedir}/lib/openqa/db
%dir %{_localstatedir}/lib/openqa/images
%{_localstatedir}/lib/openqa/testresults
%dir %{_localstatedir}/lib/openqa/share/tests
%dir %{_localstatedir}/lib/openqa/share/factory
# iso hdd repo must be geekotest writable to enable *_URL and HDD upload functionality
%dir %{_localstatedir}/lib/openqa/share/factory/iso
%dir %{_localstatedir}/lib/openqa/share/factory/hdd
%dir %{_localstatedir}/lib/openqa/share/factory/repo
%dir %{_localstatedir}/lib/openqa/share/factory/other
%ghost %{_localstatedir}/lib/openqa/db/db.sqlite
%ghost %{_localstatedir}/log/openqa

%files common
%defattr(-,root,root)
%dir %{_datadir}/openqa
%{_datadir}/openqa/lib
%exclude %{_datadir}/openqa/lib/OpenQA/Client.pm
%dir %{_localstatedir}/lib/openqa
%ghost %dir %{_localstatedir}/lib/openqa/share/
%{_localstatedir}/lib/openqa/factory
%{_localstatedir}/lib/openqa/script
%{_localstatedir}/lib/openqa/tests

%files worker
%defattr(-,root,root)
%{_sbindir}/rcopenqa-slirpvde
%{_sbindir}/rcopenqa-vde_switch
%{_sbindir}/rcopenqa-worker
%config(noreplace) %{_sysconfdir}/openqa/workers.ini
%config(noreplace) %attr(0400,_openqa-worker,root) %{_sysconfdir}/openqa/client.conf
# apparmor profile
%dir %{_sysconfdir}/apparmor.d
%config %{_sysconfdir}/apparmor.d/usr.share.openqa.script.worker
# init
%dir %{_unitdir}
%{_libexecdir}/systemd/system-generators
%{_unitdir}/openqa-worker.target
%{_unitdir}/openqa-worker@.service
%{_unitdir}/openqa-worker-no-cleanup@.service
%{_unitdir}/openqa-slirpvde.service
%{_unitdir}/openqa-vde_switch.service
%{_tmpfilesdir}/openqa.conf
%ghost %dir %{_rundir}/openqa
# worker libs
%dir %{_datadir}/openqa
%dir %{_datadir}/openqa/script
%{_datadir}/openqa/script/worker
%dir %{_localstatedir}/lib/openqa/pool
%defattr(-,_openqa-worker,root)
%dir %{_localstatedir}/lib/openqa/cache
# own one pool - to create the others is task of the admin
%dir %{_localstatedir}/lib/openqa/pool/1

%files client
%defattr(-,root,root)
%dir %{_datadir}/openqa
%dir %{_datadir}/openqa/script
%{_datadir}/openqa/script/client
%{_datadir}/openqa/script/clone_job.pl
%{_datadir}/openqa/script/dump_templates
%{_datadir}/openqa/script/load_templates
%dir %{_datadir}/openqa/lib
%{_datadir}/openqa/lib/OpenQA/Client.pm
%{_bindir}/openqa-client

%files doc
%defattr(-,root,root)
%doc docs/*

%changelog
* Tue Jun 13 2017 rd-ops-cm@suse.de
- Update to version 4.4.1497257618.89b04ed8:
  * Allow plugins to load specific configurations
  * Remove auth_config from OpenQA::WebAPI::Auth::*
  * Add fullscreen base into project
  * Add form entry for fullscreen view
  * Fix navbar to not hide if dropdown selected
  * Change help popover description in filtersection
  * Correct main controller and index page
  * Add error message for missing webserver
  * Add link to CaaSP staging (#1360)
  * Also recognize fdo bugrefs in Utils.pm (#1367)
  * Database change for bug status
  * Improve assets log messages (#1365)
  * Documentation for GRE (#1369)
  * Extend sorting by time to parent group overview (#1362)
- Include upstream changes for worker with no-cleanup
* Tue May 16 2017 mlin@suse.com
- Prequire needed group nogroup
* Thu May 11 2017 okurz@suse.com
- Re-enable dbus service installation
* Wed May 10 2017 jengelh@inai.de
- Do not suppress errors from useradd
- Rectify RPM groups
* Thu Apr  6 2017 rd-ops-cm@suse.de
- Update to version 4.4.1491400697.19ef0fc5:
  * Improve log output for label carryover
  * Ensure that label carryover is done correctly
  * Fix the recursive $db_file appending (#1279)
  * Tidy the code after last hot fix
  * Relax the regex for build values in tag: comments again
  * Don't obsolete jobs for VERSION-BUILD tagged builds
  * needle editor: Distinguish tag/area selection in check
  * needle editor: Test verification when not copying areas
  * Improve little triangle sign below a screenshot (#1285)
  * Add ignores for db.lock and phantomjs log (#1287)
* Sat Mar 18 2017 coolo@suse.com
- bump mojo requirement
* Sat Mar 18 2017 rd-ops-cm@suse.de
- Update to version 4.4.1489864450.251306a:
  * Make sure assets in pool are handled correctly
  * Call rsync of tests in a child process and notify webui
  * Move OpenQA::Cache to Worker namespace
  * Trying to make workers.ini more descriptive
  * docs: Add explanation for job priority (#1262)
  * Schedule worker reregistration in case of api-failure
  * Add more logging to job notifications
  * Use host_port when parsing URL
  * Prevent various timer loops
  * Do job cleanup even in case of api failure
* Thu Jan 19 2017 santiago.zarate@suse.com
- Add the openQA.changes file to be distributed as public/Changes on the web-ui
* Wed Jan 18 2017 rd-ops-cm@suse.de
- Update to version 4.4.1484732113.4fb90841:
  * Document filtering
  * Fix documentation generation (#1177)
  * Fix corner buttons (#1176)
  * utils: Add kernel bugzilla bugref (#1175)
  * Do not run tests for GH_PUBLISH=true
  * Mojolicious 7.19 has broken SSL support - blacklist it
  * Switch to CDN for fontawesome
  * Fix missing images in documentation (#1180)
  * Do not even run the coverage target if GH_PUBLISH is true (#1183)
* Thu Jan 12 2017 coolo@suse.com
- bump requirements to Mojo and AssetPack
* Thu Jan 12 2017 okurz@suse.com
- add Sort::Version requirement
* Thu Jan 12 2017 rd-ops-cm@suse.de
- Update to version 4.4.1484213177.5ef2a6e4:
  * Add css class to click on action (#1147)
  * client: Support sending JSON data (#1150)
  * Test both phantomjs and chrome on travis
  * Exclude AssetPack >= 1.30 - it will break fonts
  * Sort build versions correctly (#1136)
  * Add optional profiling support using Mojolicious::Plugin::NYTProf (#1153)
  * Add tests for client script
  * Don't use config file as database lock file (#1157)
  * Fix build of the package: we need a db directory to lock now
* Thu Dec 22 2016 coolo@suse.com
- remove YAML and Socket::IO::INET6 dependencies
* Wed Dec 21 2016 rd-ops-cm@suse.de
- Update to version 4.4.1482329765.866bba8:
  * Improve buttons in interactive mode
  * Fix command API route
  * Synchronize INTERACTIVE and STOP_WAITFORNEEDLE_REQUESTED
  * Change the format for developing with snapshots (#1093)
  * Fix sorting of needle table (#1092)
  * Add short route to individual job results '/t:testid:' (#1089)
  * doc: fix typo (#1096)
  * Fix AMQP reconnect timeout config var (#1098)
  * Add AMQP connection error msg to log (#1099)
* Thu Dec 15 2016 coolo@suse.com
- add new require on time::parsedate
* Thu Dec 15 2016 rd-ops-cm@suse.de
- Update to version 4.4.1481828911.8296cb4:
  * Update worker apparmor file from production worker log (#1078)
  * Add brc (Red Hat Bugzilla) and bgo (GNOME Bugzilla) labels (#1083)
  * Auditlog: display event time on hoover
  * Auditlog: add page and rows query options
  * Switch audit log to server side processing
  * Use system user to create system events
  * Add new Time modules dependencies
  * Add page displaying single event
  * Improve search query parser to support multi-word queries
  * Don't bother with event data shortening
* Fri Dec  9 2016 coolo@suse.com
- add bcond_with tests to run phantomjs optionally
* Fri Dec  9 2016 rd-ops-cm@suse.de
- Update to version 4.4.1481216307.2d2b18a:
  * worker: Prevent use of uninitialized value (#1066)
  * Copy over policies from os-autoinst
  * Fix usage of qw(SINGLE_VALUE) in use statements
  * Rework websocket server (#1057)
  * client: Respect --json also in case of an error (#1068)
  * client: Set 'Accept'-header in any case (#1070)
  * Return 404 on status update for job without worker
  * worker: Abort job if considered dead by web UI
  * Improve misleading comment
  * Comment events: Drop unneeded fedmsg conditional, include id (#1065)
  * Improve log message when job considered dead (#1075)
  * Disable carry-over for job 'labels' to support new use cases (#1071)
* Mon Nov 28 2016 oholecek@suse.com
- Do not package removed files script/migrate_images and backlog
* Mon Nov 21 2016 rd-ops-cm@suse.de
- Update to version 4.4.1479741639.90bdf0f:
  * external_reporting: Fix differing header level in description (#1012)
  * Add test for parents on index page and parent group overview (#1015)
  * Show build tags on parent-level (#1018)
  * Add a 120 column limit to .perltidyrc (#1017)
  * Fix a few formatting mistakes and remove repetitive method calls (#1020)
  * docs: Update openSUSE repos to current supported (#1021)
  * Fix URLs in dashboard when version/distri differ (#1024)
  * Show submenus on click (#1025)
  * Update bootstrap to 3.3.7
  * Wait a bit in tests if there is an ajax call
* Tue Nov  8 2016 coolo@suse.com
- update cache for bootstrap-submenu
* Tue Nov  8 2016 rd-ops-cm@suse.de
- Update to version 4.4.1478599354.3d748dc:
  * Fix job group overview without description (#957)
  * Don't free worker before artefacts are uploaded (POO #14378) (#958)
  * Improve override needle test (#962)
  * Use textareas in test suite editor (#961)
  * Fix worker error reporting when asset cannot be found (#963)
  * Make .json easier to use and include more data (#965)
  * Add API routes for job group parents (#952)
  * Hide empty job groups from index page (#967)
  * Optionaly inherit command line variables in parent (#951)
  * Add gzip and rsync to worker's AppArmor (#968)
  * Only store md5_dirname if the image is in /images (#959)
  * Fix malformed HTML
  * Fix malformed HTML (#970)
  * Prepare CACHEDIRECTORY example in workers.ini and provide profile (#969)
  * Implement Drag & Drop group editor
  * Add support for github 'bugrefs'
  * t: Delete unused (disabled) 'use Test::Output'
  * t: Ensure proper output catching
  * Improve usability of job group property editor
  * Replace all '...' with '…' in web UI
  * Add assert_script_run description
  * Allow '@' in asset name (#979)
  * Fix list of needle tags in needle info popover (#977)
  * Allow worker profile to access fixed assets
  * Fix download of fixed assets from web UI
  * Reindent 01-jobs fixtures
  * Use url helpers to map the asset path to URL
  * Add help text using popovers, title and placeholder (#983)
  * Add missing argument for hmac timestamp validation
  * Give tests without fails a no-TODO tag (#960)
  * Trying to make peace with adamw over locate_asset
  * Add a repository as test fixture to test subpaths
  * Show tags on index page
  * Add API auth tests
  * Improve help popups
  * isotovideo: Remove redundant '|| undef' (#989)
  * branding: openqa.suse.de: Update staging to current SP3 (#988)
  * Show parent groups in navbar (#974)
* Thu Oct 27 2016 coolo@suse.com
- have openqa_worker own /var/lib/openqa/cache
* Thu Oct 27 2016 rd-ops-cm@suse.de
- Update to version 4.4.1477579540.21d4009:
  * Use textareas in test suite editor (#961)
  * Fix worker error reporting when asset cannot be found (#963)
  * Make .json easier to use and include more data (#965)
  * Add API routes for job group parents (#952)
  * Hide empty job groups from index page (#967)
  * Optionaly inherit command line variables in parent (#951)
  * Add gzip and rsync to worker's AppArmor (#968)
  * Only store md5_dirname if the image is in /images (#959)
  * Fix malformed HTML (#970)
  * Prepare CACHEDIRECTORY example in workers.ini and provide profile (#969)
* Sat Oct 22 2016 rd-ops-cm@suse.de
- Update to version 4.4.1477110901.763fe71:
  * Step controller: split init into 2 functions
  * Fix coverage skipping files with 't/' in path
  * Test source view from running
  * Treat #details tab as all the others to fix back button
  * Add test for switching tabs in tests result view
  * Some fixes for the new results / running page
  * Fix SQL query to query important jobs
  * docs: Update OBS references
  * Upgrade to Leap 42.1, and fix apache2 starting problem
  * Live view: simplify drawImage
  * Be way more careful with history manipulation on results page
  * Treat # and '' the same for history management
  * Allow sha1sum for os-autoinst:2144a20c
  * Allow git for os-autoinst:d29266f
  * clone_job.pl: Add option '--skip-download'
  * Give the user better hints on what we expect for the expiry date
  * Do not create a link_post for reschedule isos
  * Use the proper API to get the data of the selected row not the first row
  * Replace the broken PNGed SVG with the real one
  * Talk to os-autoinst through HTTP instead of the file system
  * Replace document.ready with $(fn)
  * Fix interactive buttons
  * Fix upload of images during needinput
  * Make sure the worker stops at signals
  * Fix spelling of existent
  * Add web UI controls to select 20/50/100/400 previous results
  * limit_assets: when sizelimit is exceeded, remove more
  * Be more graceful when stopping the backend
  * Always set a t_finished to now if the job has a final state
  * Sort the finished jobs by their finished time
  * Change the order of the tests in the list test
  * Set a t_finished time in fixtures to have predefined order of finished jobs
  * Sort the scheduled jobs based on time
  * Sort the running jobs by Start time
  * Benefit from the hashsum calculation for our icons too
  * Remove pauseplay class and image - no longer used
  * Add more icons to assets and remove what's left in public/images
  * Remove dead file
  * Add custom whitespace squish
  * Use manual whitespace trimming after squish was removed from Mojo7
  * Mojo7 removed Mojo::URL::authority, use host_port instead
  * Add SUSE internal branding with more links
  * Refresh running modules in #details view
  * Deal with race conditions when refreshing #details
  * Create missing results tbl on #details
  * Reload broken thumbnails on test #details
  * Correct description for use of OPENQA_CONFIG
  * Fix build tagging when @ is used
  * Clarify comment in the dashboard test
  * Use correct job result in openqa events
  * Add command_enqueue to worker model as send_command
  * Export log_error helper in OpenQA::Utils
  * Add job_set_done and job_cancel to Jobs module and result set
  * Adapt tests for moved job_set_done and job_cancel
  * Remove scheduler dbus exports and subs job_set_done and cancel
  * Remove command_enqueue from scheduler and dbus
  * Check for user when emitting event
  * Log iso_cancel for canceled jobs due to new iso and allow job_cancel_by_settings event
  * Fix typo in worker check during job duplication
  * Fix counting of cancelled jobs
  * Update Jobs::cancel to accept $obsoleted option
  * Use ws_call using well known format to send messages to WS server
  * Sync property parsing to workers format
  * Make softfailed a proper final result
  * Add tests for showing softfails in prev results
  * Give user_restarted an explicit colour
  * Remove MySQL from deployments, we never test migrations or deployments
  * Resort to raw SQL instead of avoiding the schema and still use dbic
  * Fix DB access error when skipping scheduled children
  * Test both children skipping and stopping
  * Accept softfail result as passed
  * Add test scenarios for job result calculating
  * apparmor: Add missing /usr/lib/git/git
  * Make softfailed tests show the right colour
  * Make non-important failures at least a general softfail
  * Calculate softfailed at the very end to fix one specific case
  * Add more tests for corner cases
  * Carry over also for incomplete and softfailed
  * Add V1 API for comments
  * Use API for comments in web UI
  * Add comments without reloading page
  * Only redirect to running tab when no # is in url
  * Clear url hash on test step result preview close
  * Test for url hash cleanup after preview close
  * Fix incorrect 21-admin-needles test
  * Fix calculate_result (again): $overall should cover all
  * Improve error handling of comment API
  * Prevent needle editor flickering (progress #12984)
  * Enforce build order for group overview in tests
  * Remove unneeded functions of old comment API
  * Add 'latest' query route
  * Remove history for step navigations
  * Replace job_set_done by $job->done in dead job handler
  * Move dead worker check to websocket server
  * Add test for dead worker detection
  * Make build in previous view a link to tests overview
  * Add test for 'todo=1' query param
  * t: Fix typo in t/ui/18-tests-details.t
  * Fix deadworker timer function reference
  * Fix complex_query and its usage in last route
  * Render links on 'latest' route directly instead of redirect
  * templates: Simplify single line statements
  * Make title for 'previous results' a proper heading
  * t: 12-needle-edit.t: Try to find overwrite warning more often (poo#12980)
  * previous: Move current limit where other options are
  * Add web UI controls to select more builds in group_overview
  * Add web UI controls to filter only tagged or all builds
  * Fix workaround label
  * Fix taking over tags from a workaround needle
  * worker: Remove tons of work arounds and quirks in upload
  * Allow cksum to be called in the worker
  * Upload assets as temporary files and only rename after chksum check
  * Fix typo
  * Prevent use of non-existing route in upload_status
  * templates: live: Fix url_for over 'latest' route
  * Disable auto-duplication of jobs (poo#13042)
  * Avoid shift
  * Test handling deleted needles in needle editor
  * Ignore deleted needles when showing needle editor
  * Show warning about deleted/bad needles (needle editor)
  * Fix admin layout for test suites with long keys Currently test suites slenkins-tests-ceph-control and s390_hsi-l2
  * Make apache follow symlinks for assets directory
  * Fix '0' duration for previous jobs on running or scheduled job
  * Add link to latest job in each scenario
  * Allow pinning comments as group description
  * Fix jobs templates layout
  * Also filter 'machine' on latest
  * Vertically align progress bar with build number
  * Re-add boundary hack
  * Make 'latest' link more explicit
  * Do not quote identifiers, solves problem with uppercase column (#838)
  * use /var/lib/openqa/share/factory/iso path (#849)
  * Add 'bash' to be able to run 'CMD' (#850)
  * Add filter from in test overview (#852)
  * Draw needle match labels after match boxes (#851)
  * Add lock barriers (#845)
  * Show custom error pages (#831)
  * README: Update coveralls icon by .svg version (#853)
  * Add new job state (#848)
  * Remove old comment code (#856)
  * Run optipng on the worker while uploading images (#858)
  * Add filter for all states and results
  * Distinguish comment events
  * Show results and states dynamically
  * Test whether job still exists in reduce_result
  * Split Logging support out of WebAPI (#860)
  * Give the scheduler a home (#862)
  * Log status update without worker (#861)
  * dead worker check: use 15 secs not 10, better names, comments (#864)
  * Fix the stale job calculation for uploading jobs (#865)
  * Fix path in docs about migrating db schema
  * Show filter on top and display current filter
  * Avoid HMAC timestamp mismatch during large file upload (#871)
  * Give Websockets and Scheduler the home of the webapi (#870)
  * Label builds where all tests passed as reviewed
  * Dont grab twice (#874)
  * Prevent detecting occurrences like bsc#2436346bla as bugref
  * Replace URLs with the appropriate bugref pattern
  * Do not rely on WebAPI to find home - require and use an harmless class (#876)
  * Prevent multiple bug refs per comment to yield incorrect URLs
  * Add 'match' query parameter for index page
  * Add 'group' query parameter for index page
  * Add more faking to FakeApp - so restarting jobs works again (#880)
  * comment the home detection for scheduler/websockets better
  * Allow bugrefs being separated by any non-word chars
  * Fix used needle indication when needles are in folders
  * Merge match and group parameter
  * Use $FindBin::RealBin to resolve links for client script (#889)
  * Fix previous jobs showing up for different machine (#885)
  * Remove FIXMEs and disabled code in t/ui/15-comments.t (#888)
  * notify workers when job with chained children done (POO #13746) (#883)
  * Pass encoded URL filter parameter correctly (#890)
  * Reintegrate job duplicate (#875)
  * Mark worker alive for all kind of artefacts (#894)
  * Small schema change to add an index (#895)
  * Add IPC debug to websockets too to debug hangs (#896)
  * update apparmor profiles for ppc64le (#892)
  * Try harder to avoid long running pre-processing (#897)
  * Increase session expiration from 1 to 48 hours (#900)
  * Make ws_send_all WebSocket call not waiting for results (#902)
  * Avoid DBUS dead locks (#901)
  * Do not manually render anything on websocket creation (#903)
  * Prevent error message in log as 'scheduled' jobs are also 'inprogress' (#906)
  * Add scenario params to limit URLs for previous results (#893)
  * Handle links to bugs already formatted correctly (#905)
  * Improve documentation about PosgreSQL (#904)
  * Test time_limit_days query parameter (#907)
  * Fix comments test (#908)
  * Split the images directory even more (#739)
  * Add anchor links to comments (#909)
  * Move comments.css to sass reduce copy&paste (#910)
  * Readd the lost name of the thumb_nail route (#911)
  * Refactor computing build results (#898)
  * Show incomplete/skipped bugs, show tooltip on progress bars (#912)
  * Add link to openQA review (#899)
  * Fix vertical alignment of progress bars in tables (#917)
  * Show progress indication in admin needle table (#918)
  * Track image assets better (#919)
  * Fix deletion of multiple needles at once (#921)
  * fix downloading assets to different filename
  * Fix sorting in admin needle table (#924)
  * Add JSON representation of index and group overview (#922)
  * Add filter form for index page (#923)
  * Add /index.json route and test it together with overview.json (#925)
  * Fix /index.json route to pass the format (#926)
  * Fix softfailed results not showing in tests list (#930)
  * Fix group filter on index when param is empty (#933)
  * Fix group overview when no builds shown (#932)
  * t: Add 'Test::Warnings' where missing; Catch all warnings in tests again (#931)
  * Extend schema of JobGroups (#914)
  * Fix typos (#935)
  * reuse a constant boundary to make debugging failed uploads a little easier (#934)
  * Some code cleanup and more tests (#937)
  * Fix test result info spacing (#938)
  * fix loch ness monster bug in 14-grutasks.t (#941)
  * Load step and needles for failedmodules link async (#936)
  * Complete API for job groups (#942)
  * Auto reload result page on state sched -> running (#940)
  * Update Installing.asciidoc (#927)
  * Go to bugzilla.suse.com also for bnc# (#943)
  * Fix going to bugzilla.suse.com also for bnc# (#946)
  * Improve error handling when deleting needle (#939)
  * Fix needle deletion via Git (#948)
  * WebAPI: Delete comments stating the obvious + delete unused routes (#947)
  * Render bugref links in thumbnail text windows
  * Test render bugref links in thumbnail text windows
  * Show job group description (#950)
  * Add 'fixed' asset subdirectories for fixed assets (#928) (#945)
  * use locate_asset in register_assets_from_settings (#954)
  * Rejig compressed asset download, don't leave compressed files (#955)
  * Fix registration of downloaded assets (broken by 0905559b) (#953)
  * List needle tags + step icons (#944)
* Tue Sep 20 2016 oholecek@suse.com
- Add missing dependency perl(JSON) for openqa-client
* Mon Sep 19 2016 oholecek@suse.com
- Add missing dependencies perl(Data::Dump) and perl(Getopt::Long)
  for openqa-client
* Sat Sep 17 2016 oholecek@suse.com
- Add symlink /usr/bin/openqa-client to /usr/share/openqa/script/client
* Thu Sep  8 2016 oholecek@suse.com
- Ghost /var/lib/openqa/share in common subpackage
  * solves issues when updateing worker with mounted NFS
* Mon Aug 22 2016 oholecek@suse.com
- Remove perl(Perl::Critic) build requirement, added by mistake
* Mon Aug 22 2016 oholecek@suse.com
- Package /var/lib/openqa/share for common subpackage
- Pakcage /var/lib/openqa/share/factory/[iso|hdd|other|..] for openQA package
* Sat Jul  9 2016 coolo@suse.com
- Update base version to 4.4 to express new API of isotovideo
* Mon Jun 20 2016 rd-ops-cm@suse.de
- Update to version 4.3.1466434215.021a11c:
  * No longer export the worker_id as hash entry
  * Remove job_get from the scheduler
  * Simplify our theme - split the sass theme from the specifcs
  * Set an explicit colour on cancelled
  * Use default bootstrap table class for striping
  * Use the theme colour in tables
  * Have our bootstrap theme based on https://bootswatch.com/paper/
  * Fix comments test - h2 is the new h1
* Wed Jun  1 2016 rd-ops-cm@suse.de
- Update to version 4.3.1464792258.155f49e:
  + t: Use helper function to wait for ajax
  + Extend iso post TEST parameter to support a list of tests (poo#10482)
  + Test for "let TEST parameter support a list of tests"
  + Enable brackets inside keys in client script
  + Add first approach for editable comments
  + Make comments for tests editable, too
  + Fix indentation of flash and wells on test page
  + Fix minor mistakes in editable comments
  + Reduce code-dublication in templates
  + Add first approach to test editable comments
  + Test comment editing in test results, too
  + Check for current user in commenting functions
  + Adjust t/17-labels_carry_over.t to reflect changes
  + Add css class no_hover to all /thumbs/
  + Improve TEST parameter to support a list of tests
  + needlediff: Improve similarity text look
  + Use the nice audio icon (with the correct size)
  + Use nice icon for wait_serial
  + add a config setting to specify asset types not to link to
  + Increase left padding of status icons
  + Prevent error in group_overview with '-important' builds
  + Check database configuration with better user feedback
  + Fix broken string compare slipping into wait_serial icon change
  + Fix non-ASCII characters in comments
  + Allow admins to delete any comments
  + Fix showing editing buttons
  + Fix regexp for multiple parent jobs
  + Fix typo in 05-scheduler-restart-and-duplicate.t
  + Improve log message about 'setup failure'
  + Support tests/export to get a text format for archives
  + Fix re-enabling current user role
  + Adapt to latest AssetPack
* Sun Apr 10 2016 oholecek@suse.com
- add perl(Archive::Extract) dependency (needed by PR#627)
* Tue Mar 22 2016 oholecek@suse.com
- create openQA-client and openQA-doc subpackages
- remove DB handling, it's done by openQA itself now
* Wed Feb 17 2016 coolo@suse.com
- adapt to adam's changes
* Mon Feb 15 2016 lnussel@suse.de
- remove user migration code. no such systems should exist anymore
* Thu Jan 14 2016 oholecek@suse.com
- update base version to 4.3
* Fri Jan  8 2016 oholecek@suse.com
- add modify_needle script
* Mon Oct 26 2015 oholecek@suse.com
- add create_admin script
* Tue Sep  8 2015 oholecek@suse.com
- add perl(IPC::Run) dependency (needed by PR#414)
* Mon Aug 31 2015 lnussel@suse.de
- we don't need JSON::RPC::Legacy::Client
* Mon Jul  6 2015 lnussel@suse.de
- fix rpmlint warnings
* Wed Jul  1 2015 oholecek@suse.com
- add openqa-scheduler.service and openqa-websockets.service
* Wed Jun 24 2015 lnussel@suse.de
- fix fileliist for missing service files
* Wed Jun 17 2015 oholecek@suse.com
- package dbus system policy config
- add perl(Net::DBus) to requires
* Wed Apr  8 2015 coolo@suse.com
- add openqa-gru.service
* Wed Mar 18 2015 lnussel@suse.de
- keep /lib/openqa/share in webui and the symlink in -common. So a
  plain worker owns no files in share
* Mon Mar  9 2015 lnussel@suse.de
- add --from=geekotest to chown call just to be on the safe side
* Mon Mar  9 2015 coolo@suse.com
- create a 2nd user and migrate the worker from geekotest to
  _openqa-worker
* Sat Feb 28 2015 coolo@suse.com
- run preparetool from the right %%post
* Thu Feb 26 2015 oholecek@suse.com
- fix missing ini files link and package new config dir (boo#919548)
* Wed Feb 25 2015 sfalken@opensuse.org
- Changed path for fetchneedles in post-install echo
* Mon Feb 23 2015 oholecek@suse.com
- don't move ini files in spec, Makefile does it now
* Thu Feb 19 2015 lnussel@suse.de
- include fetchneedles in file list
* Tue Feb 17 2015 rd-ops-cm@suse.de
- Update to version 4.1424166204.2ca1601:
  + Refactor worker scripts and add locking support
  + Pass worker port to os-autoinst and remove :jobid check
  + assets replaced /diskimages long ago - get rid of it
  + avoid "openQA: openQA" as title on main page - looks just silly
  + remove lib/OpenQA from include path - not needed
  + fix make test to be coverable and use it in .travis.yml
  + switch default auth_module to Fake
  + adding a test to test /admin/machines using phantomjs
  + skip the tests if phantomjs is not installed
* Fri Feb 13 2015 oholecek@suse.com
- we don't need MojoX::JSON::RPC
* Thu Jan 29 2015 lnussel@suse.de
- reduce mojo require to 5.60
* Wed Jan 28 2015 lnussel@suse.de
- require qemu in worker to get kvm group
- add geekotest user to kvm group in worker's %%post as qemu is not required by
  the web ui
* Wed Jan 28 2015 coolo@suse.com
- fix requires
* Wed Jan 28 2015 coolo@suse.com
- make it version 4 and require os-autoinst of version 4 too
* Fri Jan  9 2015 oholecek@suse.com
- add BuildRequire perl(Test::Compile)
* Sun Dec 21 2014 lnussel@suse.de
- pre-require openQA-common to make sure the user is created
* Sun Nov 30 2014 coolo@suse.com
- we don't require png2theora any longer - and actually openQA-worker
  never did
* Mon Nov 17 2014 oholecek@suse.com
- fix upgrade scenario from openQA to openQA-common
* Thu Nov 13 2014 oholecek@suse.com
- split to openQA, openQA-common and openQA-worker packages
* Thu Oct 30 2014 mlin@suse.com
- fix post script - remove buildroot macro
* Fri Aug 29 2014 lnussel@suse.de
- don't enable systemd files in %%post!
* Tue Aug 12 2014 dvlaeev@suse.com
- Build as noarch package
* Fri Aug  1 2014 lnussel@suse.de
- require git-core as it's needed by testsuite
* Thu Jul 17 2014 oholecek@suse.cz
- add perl(aliased) requirement
* Wed Jun 25 2014 lnussel@suse.de
- remove apache conf.d file
* Thu Jun 12 2014 lnussel@suse.de
- create log file in package
* Tue May 20 2014 lnussel@suse.de
- restart boot.apparmor on update
* Mon May 19 2014 lnussel@suse.de
- disable tidy test
* Wed May 14 2014 lnussel@suse.de
- recommend instead of require apparmor
- restart apparmor on update
* Wed Apr 30 2014 lnussel@suse.de
- load_dbdata no longer needed
* Fri Apr 11 2014 alarrosa@suse.com
- Load the data for the opensuse usage case into the database during %%post
* Tue Apr  8 2014 alarrosa@suse.com
- Added a dependency on perl(YAML) which is required by initdb and upgradedb
* Mon Apr  7 2014 alarrosa@suse.com
- upgrade.pl was renamed to upgradedb
* Mon Apr  7 2014 alarrosa@suse.com
- require perl(SQL::SplitStatement)
- Initializes or upgrade the database as needed in %%post
* Fri Mar 28 2014 lnussel@suse.de
- require perl(DBIx::Class::DeploymentHandler)
- add /var/lib/openqa/cache to file list
* Thu Mar 27 2014 lnussel@suse.de
- use prove instead of make test
* Thu Mar 27 2014 lnussel@suse.de
- add GHC, Mojolicious::Plugin::CHI and Cache::Cache as dependency
* Fri Mar 21 2014 mhrusecky@suse.cz
- rc symlinks for webui and workers
* Fri Mar 21 2014 coolo@suse.com
- fix dependencies on JSON client
* Mon Mar 17 2014 coolo@suse.com
- change version format in _service file
* Fri Mar 14 2014 coolo@suse.com
- move the openqa.ini to /etc and mark it noreplace
* Wed Mar 12 2014 coolo@suse.com
- require perl(LWP::Protocol::https) for openid support
* Wed Mar 12 2014 coolo@suse.com
- bump version to 3 so we can differ it from v2
- require systemd and old JSON::RPC - needs porting
* Wed Mar 12 2014 coolo@suse.com
- install apache templates and enable the systemd services
* Thu Mar  6 2014 lnussel@suse.de
- add perl(Image::Magick) requirement
* Tue Mar  4 2014 lnussel@suse.de
- add perl(Net::OpenID::Consumer) requirement
* Mon Mar  3 2014 lnussel@suse.de
- add perl(DateTime::Format::SQLite) requirement
* Fri Feb 28 2014 lnussel@suse.de
- add systemd macros
* Mon Feb 24 2014 mlin@suse.com
- update the fileslist and the post script
* Mon Feb 24 2014 mlin@suse.com
- require Date::Format and File::Copy::Recursive
- update the filelist
* Mon Feb 17 2014 lnussel@suse.de
- require SQL::Translator
* Wed Feb 12 2014 mlin@suse.com
- add openQA's apparmor profile usr.share.openqa.script.openqa
* Wed Feb 12 2014 mlin@suse.com
- add perl(Config::IniFiles) as Requires
- remove /etc/default/openqa
* Thu Feb  6 2014 lnussel@suse.de
- fix filelist and run testsuite
* Wed Jan 22 2014 coolo@suse.com
- use remote services to hook
* Fri Jul 26 2013 lnussel@suse.de
- update to git head, add new requirement File::Copy::Recursive
* Thu Jun 13 2013 lnussel@suse.de
- use primary group "nogroup"
* Tue May 14 2013 lnussel@suse.de
- initial package
